% analytical model to determine balance between incision and transverse sediment transport
% for explanation, see Supplement 2 of the paper "Critical dependence of morphodynamic models of fluvial and tidal systems on empirical downslope sediment transport"

% author: Anne Baar

clear all
close all
clc

%% input
% one of these parameters can be a vector
beta = 15;              % transverse slope effect (abn)
k = [3,4,5];            % non linearity sediment transport 
C = 42;                 % Chezy roughness
S = 5e-4;               % channel slope
D50 = 5e-4;             % median grain size
g = 9.81;               % gravity

X = k; % SPECIFY WHICH PARAMETER IS A VECTOR


% other input
dh = 0:0.01:3.5;        % bed level difference (size of perturbation)
W_ref = 5:0.1:300;      % channel width
a = 12.5;               % ratio between channel width and discharge


%% analytical model
n = 3;                  % nr gridcells
w = W_ref./n;           % width of grid cell


helling = zeros(length(dh),length(X));

for tel1 = 1:length(dh)


    %% calculate h and u

        D = C.*S.^0.5;
        Dim = (1.65*g).^0.5.*D50.^(3/2);
        Q_ref = a.*W_ref;


        h=0.2; %estimation of water depth (m)
        htemp=1.1*h; 
        while abs(h-htemp)>1e-6;
            htemp=(h+htemp)/2;                  % Temporary water depth (m)
        %     C=18*log10((12*htemp)/ks);        %Temporary Chezy (m^0.5/s) 
            utemp= htemp.^0.5.*D;               %Temporary flow velocity (m/s)
            h=a./(utemp);            %the real water depth (m)

        end

        h2 = h;
        u = a./(h);
        theta = u.^2./(1.65.*C.^2.*D50);

        fr = u./(9.81*h).^0.5;


        % upstream
        h_i = h;
        u_i = u;

        % downstream
        h_1 = h_i - 0.5.*dh(tel1); 
        h_2 = h_i + dh(tel1);                             
        h_3 = h_i - 0.5.*dh(tel1);                        
        h_av = (h_1+h_2+h_3)./n;    
        u_av = h_av.^0.5.*D;

        % equilibrium W
         W_eq2 =  (h_1.^(k/2))./(h_2.^(k/2) - h_i.^(k/2)) .* beta.*dh(tel1).*9.*C.*(1.65.*D50).^0.5./u_av ;               

    helling(tel1,:) = theta.^0.5.*W_eq2./h2./beta;
    hold on
end

    
%% figure
plot(dh,helling,'Linewidth',2)
hold on
        
yl = ylabel('channelization factor ($$\frac{\sqrt{\theta}}{\beta} \frac{W}{h}$$)');
set(yl,'Interpreter','latex')
xlabel('size of perturbation (\Delta h)')
% xlim([0, 3.5])
% ylim([1 100])

set(gca,'yscale','log','Fontsize',12);%,'Ytick',[2,10,80],'Yticklabel',[2,10,8])
box on
